.. _Bootstrap 3: https://getbootstrap.com/docs/3.3/


==============
djk-bootstrap3
==============

.. _django-jinja-knockout: https://github.com/Dmitri-Sintsov/django-jinja-knockout

`Bootstrap 3`_ UI for `django-jinja-knockout`_.

https://github.com/nakupanda/bootstrap3-dialog
